@@ -1,4 +1,4 @@
-#! /bin/bash
+#! /usr/bin/env bash
 
 if [ ! -f 'build.sh' ]; then
 	echo 'ERROR: This script must be run from the directory it is in' >&2
@@ -20,6 +20,13 @@ INSTDIR="$(pwd)/inst"
 PATCHDIR="$(pwd)/patches"
 export MK4VERS SRC SRCURL BUILDDIR OUTDIR INSTDIR PATCHDIR
 
+# Set configure options for this sub-project
+LDFLAGS="${KC_MK4TCL_LDFLAGS}"
+CFLAGS="${KC_MK4TCL_CFLAGS}"
+CPPFLAGS="${KC_MK4TCL_CPPFLAGS}"
+LIBS="${KC_MK4TCL_LIBS}"
+export LDFLAGS CFLAGS CPPFLAGS LIBS
+
 rm -rf 'build' 'out' 'inst'
 mkdir 'build' 'out' 'inst' || exit 1
 
@@ -115,8 +122,8 @@ fi
 		fi
 
 		(
-			echo "Running: ./configure $tryopt --prefix=\"${INSTDIR}\" --exec-prefix=\"${INSTDIR}\" --with-tcl=\"${TCLCONFIGDIR}/../generic\" ${CONFIGUREEXTRA}"
-			./configure $tryopt --prefix="${INSTDIR}" --exec-prefix="${INSTDIR}" --with-tcl="${TCLCONFIGDIR}/../generic" ${CONFIGUREEXTRA}
+			echo "Running: ./configure $tryopt --prefix=\"${INSTDIR}\" --exec-prefix=\"${INSTDIR}\" --libdir=\"${INSTDIR}/lib\" --with-tcl=\"${TCLCONFIGDIR}/../generic\" ${CONFIGUREEXTRA}"
+			./configure $tryopt --prefix="${INSTDIR}" --exec-prefix="${INSTDIR}" --libdir="${INSTDIR}/lib" --with-tcl="${TCLCONFIGDIR}/../generic" ${CONFIGUREEXTRA}
 
 			echo "Running: ${MAKE:-make} tcllibdir=\"${INSTDIR}/lib\" AR=\"${AR:-ar}\" RANLIB=\"${RANLIB:-ranlib}\""
 			${MAKE:-make} tcllibdir="${INSTDIR}/lib" AR="${AR:-ar}" RANLIB="${RANLIB:-ranlib}" || exit 1
