@@ -1,4 +1,4 @@
-#! /bin/bash
+#! /usr/bin/env bash
 
 if [ ! -f 'build.sh' ]; then
 	echo 'ERROR: This script must be run from the directory it is in' >&2
@@ -20,6 +20,13 @@ INSTDIR="$(pwd)/inst"
 PATCHSCRIPTDIR="$(pwd)/patchscripts"
 export SRC SRCURL BUILDDIR PATCHDIR OUTDIR INSTDIR PATCHSCRIPTDIR
 
+# Set configure options for this sub-project
+LDFLAGS="${KC_TK_LDFLAGS}"
+CFLAGS="${KC_TK_CFLAGS}"
+CPPFLAGS="${KC_TK_CPPFLAGS}"
+LIBS="${KC_TK_LIBS}"
+export LDFLAGS CFLAGS CPPFLAGS LIBS
+
 # Must be kept in-sync with "../tcl/build.sh"
 TCLFOSSILDATE="../tcl/src/tcl${TCLVERS}.tar.gz.date"
 export TCLFOSSILDATE
@@ -49,7 +56,11 @@ if [ ! -f "${SRC}" ]; then
 	elif echo "${TCLVERS}" | grep '^fossil_' >/dev/null; then
 		use_fossil='1'
 
-		FOSSILTAG=$(echo "${TCLVERS}" | sed 's/^fossil_//g')
+		if echo "${TCLVERS}" | grep '^fossil_.*_tk=' >/dev/null; then
+			FOSSILTAG=$(echo "${TCLVERS}" | sed 's/^fossil_.*_tk=//g')
+		else
+			FOSSILTAG=$(echo "${TCLVERS}" | sed 's/^fossil_//g')
+		fi
 	fi
 
 	if [ -d 'buildsrc' ]; then
@@ -177,11 +188,11 @@ fi
 		fi
 
 		if [ "${STATICTK}" = "1" ]; then
-			echo "Running: ./configure --disable-shared --disable-symbols --prefix=\"${INSTDIR}\" --with-tcl=\"${TCLCONFIGDIR}\" ${CONFIGUREEXTRA}"
-			./configure --disable-shared --disable-symbols --prefix="${INSTDIR}" --with-tcl="${TCLCONFIGDIR}" ${CONFIGUREEXTRA}
+			echo "Running: ./configure --disable-shared --disable-symbols --prefix=\"${INSTDIR}\" --libdir=\"${INSTDIR}/lib\" --with-tcl=\"${TCLCONFIGDIR}\" ${CONFIGUREEXTRA}"
+			./configure --disable-shared --disable-symbols --prefix="${INSTDIR}" --libdir="${INSTDIR}/lib" --with-tcl="${TCLCONFIGDIR}" ${CONFIGUREEXTRA}
 		else
-			echo "Running: ./configure --enable-shared --disable-symbols --prefix=\"${INSTDIR}\" --with-tcl=\"${TCLCONFIGDIR}\" ${CONFIGUREEXTRA}"
-			./configure --enable-shared --disable-symbols --prefix="${INSTDIR}" --with-tcl="${TCLCONFIGDIR}" ${CONFIGUREEXTRA}
+			echo "Running: ./configure --enable-shared --disable-symbols --prefix=\"${INSTDIR}\" --libdir=\"${INSTDIR}/lib\" --with-tcl=\"${TCLCONFIGDIR}\" ${CONFIGUREEXTRA}"
+			./configure --enable-shared --disable-symbols --prefix="${INSTDIR}" --libdir="${INSTDIR}/lib" --with-tcl="${TCLCONFIGDIR}" ${CONFIGUREEXTRA}
 		fi
 
 		echo "Running: ${MAKE:-make}"
