@@ -1,4 +1,4 @@
-#! /bin/bash
+#! /usr/bin/env bash
 
 if [ ! -f 'build.sh' ]; then
 	echo 'ERROR: This script must be run from the directory it is in' >&2
@@ -19,6 +19,13 @@ OUTDIR="$(pwd)/out"
 INSTDIR="$(pwd)/inst"
 export ZLIBVERS SRC SRCURL BUILDDIR OUTDIR INSTDIR
 
+# Set configure options for this sub-project
+LDFLAGS="${KC_ZLIB_LDFLAGS}"
+CFLAGS="${KC_ZLIB_CFLAGS}"
+CPPFLAGS="${KC_ZLIB_CPPFLAGS}"
+LIBS="${KC_ZLIB_LIBS}"
+export LDFLAGS CFLAGS CPPFLAGS LIBS
+
 rm -rf 'build' 'out' 'inst'
 mkdir 'build' 'out' 'inst' || exit 1
 
@@ -54,8 +61,8 @@ fi
 
 	# We don't pass CONFIGUREEXTRA here, since this isn't a GNU autoconf
 	# script and will puke
-	echo "Running: ./configure --prefix=\"${INSTDIR}\""
-	./configure --prefix="${INSTDIR}"
+	echo "Running: ./configure --prefix=\"${INSTDIR}\" --libdir=\"${INSTDIR}/lib\""
+	./configure --prefix="${INSTDIR}" --libdir="${INSTDIR}/lib"
 
 	echo "Running: ${MAKE:-make} AR=\"${AR}\""
 	${MAKE:-make} AR="${AR}" || exit 1
